
`tl.load` reads tensors from GPU memory; `tl.store` writes tensors to GPU memory
Image: Public domain, via Wikimedia Commons
`tl.load` reads tensors from GPU memory; `tl.store` writes tensors to GPU memory
tl.dot does in Triton: block-level matrix multiply using tensor cores
tl.dot performs block-level matrix multiplication using tensor cores in Triton
to write a vector addition kernel in Triton: load blocks, add, store
```
a Triton @triton.jit decorator does: compiles a Python function into a GPU kernel
@triton.jit decorator compiles Python function into a GPU kernel
CPU cache
L1/L2 cache hierarchy reduces global memory latency
a Triton kernel is
Can your phone run faster with a different brain?
Triton differs from CUDA
Why does a super-fast computer sometimes run slower than a regular one?
Swipe through 100 ML concepts daily
Open Pocket Polymath